PyPlate
=======

A Python package for processing astronomical photographic plates

## Installation

Install with basic requirements:

`pip install pyplate`

Add dependencies for artifact classification and multi-exposure pattern finding:

`pip install pyplate[ml]`

Add PostgreSQL support:

`pip install pyplate[pgsql]`

Add MySQL support:

`pip install pyplate[mysql]`

Install development version from GitHub:

`pip install git+https://github.com/astrotuvi/pyplate.git`

## Documentation

[PyPlate documentation](https://pyplate.readthedocs.io/)
